export interface Constructor {
    publicApiKey: string;
    env: string;
}
export declare enum UserEventType {
    FeatureViewed = "featureViewed"
}
export interface AppUser {
    id?: string;
    email?: string;
    data?: {
        [key: string]: any;
    };
}
export interface User {
    _id: string;
    applicationId: string;
    email: string;
    externalId: string;
    env: string;
    lastVisitedOn: Date;
    createdOn: Date;
    updatedOn: Date;
    deletedOn?: Date | null;
}
export interface JSONObject {
    [x: string]: JSONValue;
}
export declare type JSONValue = string | number | boolean | {
    [x: string]: JSONValue;
} | Array<JSONValue>;
export interface FetchFlagsParams {
    env: string;
    userId?: string;
}
export interface CreateUserParams {
    id?: string;
    email?: string;
    data?: {
        [key in string]: any;
    };
}
export declare type CreateUserData = {
    env: string;
} & CreateUserParams;
export interface CreateUserEventData {
    userId: string;
    type: UserEventType;
    data: {
        featureName?: string;
    };
}
export interface LocalStorageData {
    features: {
        [key in string]: boolean;
    };
    configs: {
        [key in string]: JSONObject;
    };
    user?: User;
}
export declare type FeatureOverride = {
    name: string;
    enabled: boolean;
};
declare class FeatureFlags {
    private _apiKey;
    private _env;
    private _user?;
    private _features;
    private _featureOverrides;
    private _configs;
    constructor({ publicApiKey, env }: Constructor);
    fetchFeatureFlags(user: AppUser): Promise<any>;
    isOn(featureName: string): boolean;
    private mergeFeatures;
    setFeatures(featureOverrides: FeatureOverride[]): void;
    getFeature(featureName: string, options?: {
        defaultConfig?: JSONObject;
    }): {
        name: string;
        enabled: boolean;
        config: JSONObject | undefined;
    };
    getConfig(featureName: string, defaultConfig?: JSONObject): JSONObject | undefined;
    trackFeatureView(featureName: string): Promise<void>;
    private _fetchFlags;
    private _createUser;
    private _saveToStorage;
    private _getFromStorage;
}
declare const _default: {
    create: ({ publicApiKey, env }: Constructor) => FeatureFlags;
};
export default _default;
